Struct FilePosition

pub struct FilePosition(/* private fields */);
A 32-bit numerical value, starting from zero, that indicates the location of a byte in a file.

FilePosition is primarily used by the lexer to record the source location in the preprocessed translation unit of every token. This information is later used when emitting diagnostics to include the relevant source code.

A 4 GB C source file should be enough for anybody, right?