Struct SourceLocation

pub struct SourceLocation {
    pub file_pos: FilePosition,
    pub length: u32,
}
The location and span of a token in the preprocessed translation unit.

Fields

file_pos: FilePositionlength: u32

Implementations



impl SourceLocation

pub fn new(file_pos: FilePosition, length: usize) -> Self

Creates a new source location for the given file position and length in bytes.

pub fn none() -> Self

Creates a new source location which indicates a ‘null’ / no value.

pub fn merge_with(self, other: SourceLocation) -> Self

Merges this and the other location into a new location, taking the union of the two.

pub fn set_span_up_to_location(&mut self, other: &SourceLocation)

Modifies this location’s length so that this location’s span finishes immediately before the given other one begins.

This function will shrink or extend this location’s length depending on the other one’s start position. The other location must start after this one, or otherwise the operation is a no-op.

pub fn get_next_location(&self) -> SourceLocation

Gets the next source location, of length 1, after this one.